//-----------------------------------------------------------------------
// <copyright file="TerminateInstances.cs" company="Microsoft">
// Copyright (c) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY 
// KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
// </copyright>
//-----------------------------------------------------------------------
namespace Microsoft.Sdc.Tasks.BizTalk2006.Orchestration
{
    /// <summary>
    /// Terminates any running instances of the BizTalk Orchestration.
    /// </summary>
    /// <remarks>
    /// <code>
    /// <![CDATA[<BizTalk2006.Orchestration.TerminateInstances AssemblyName = "assemblyname" Name="name" Server="server" Database="database" />]]>
    /// </code>
    /// <para>where:</para>
    /// <para><i>assemblyName (Required)</i></para>
    /// <para>
    /// The name of the assembly that contains the orchestration.
    /// </para>
    /// <para><i>name (Required)</i></para>
    /// <para>
    /// The name of the orchestration to TerminateInstances.
    /// </para>
    /// <para><i>server</i></para>
    /// <para>
    /// The logical name of the server Orchestrationing the BizTalk management database. If neither this nor the
    /// database name are specified then the installation will default to the local installation.
    /// </para>
    /// <para><i>database</i></para>
    /// <para>
    /// The name of the BizTalk management database. If neither this nor the server name are specified 
    /// then the installation will default to the local installation.
    /// </para>
    /// <para><i>username</i></para>
    /// <para>
    /// The username to use to connect to the database if using SQL Server security. The default is to
    /// connect using Windows Integrated security.
    /// </para>
    /// <para><i>password</i></para>
    /// <para>
    /// The password to use to connect to the database if using SQL Server security. The default is to
    /// connect using Windows Integrated security.
    /// </para>
    /// </remarks>
    /// <example>
    /// <code><![CDATA[
    /// <Project>
    ///     <Target Name="Test" >
    ///            <BizTalk2006.Orchestration.TerminateInstances
    ///                AssemblyName="EAIOrchestrations, Version=1.0.0.0, Culture=neutral, PublicKeyToken=a0cf43ab166707e8"
    ///                Name="EAIOrchestrations.EAIProcess" />
    ///     </Target>
    /// </Project>
    /// ]]></code>    
    /// </example>
    public class TerminateInstances : BizTalk2004.Orchestration.TerminateInstances
    {
        private string application;

        /// <summary>
        /// Gets or sets the application.
        /// </summary>
        /// <value>The application.</value>
        public string Application
        {
            get { return this.application; }
            set { this.application = value; }
        }
    }
}
