//-----------------------------------------------------------------------
// <copyright file="DeleteKeyTree.cs" company="Microsoft">
// Copyright (c) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY 
// KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
// </copyright>
// <author>Jim Hartill</author>
// <email>jameshar@microsoft.com</email>
// <date>2004-07-12</date>
// <summary>Deletes a Registry Key and all subkeys in a specified hive on a specified machine.</summary>
//-----------------------------------------------------------------------

namespace Microsoft.Sdc.Tasks.Registry
{
    using System;
    using System.Reflection;
    using System.Collections;
    using System.Security;
    using System.Runtime.InteropServices;
    using Microsoft.Sdc.Tasks;
    using Microsoft.Win32;
    using Microsoft.Build.Framework;

    /// <summary>
    /// 
    /// </summary>
    public class DeleteKeyTree : TaskBase
    {
        private string value;
        private string key;

        private string machineName;
        private string registryHive;

        [Required]
        public string RegistryHive
        {
            get
            {
                return (registryHive == null ? String.Empty : registryHive);
            }

            set
            {
                registryHive = value;
            }
        }

        /// <summary>
        /// Defaults to local machine if not specified.
        /// </summary>
        /// <value></value>
        public string MachineName
        {
            get
            {
                return (machineName == null ? String.Empty : machineName);
            }
            set
            {
                machineName = value;
            }
        }

        /// <summary>
        /// If not specified then the default for the key is returned.
        /// </summary>
        /// <value></value>
        public string Value
        {
            get
            {
                return (value == null ? String.Empty : value);
            }

            set
            {
                this.value = value;
            }
        }

        [Required]
        public string Key
        {
            get
            {
                return (key == null ? String.Empty : key);
            }

            set
            {
                key = value;
            }
        }

        /// <summary>
        /// </summary>
        public DeleteKeyTree()
        {
        }


        /// <summary>
        /// Performs the action of this task.
        /// </summary>
        protected override void InternalExecute()
        {
            Microsoft.Win32.RegistryHive hive = (Microsoft.Win32.RegistryHive)Enum.Parse(typeof(Microsoft.Win32.RegistryHive), this.registryHive, true);
            try
            {
                RegistryKey.OpenRemoteBaseKey(hive, this.MachineName).DeleteSubKeyTree(this.Key);
            }
            catch (ArgumentException)
            {
                throw new TaskException("Registry.Argument", Key, MachineName);
            }
            catch (SecurityException)
            {
                throw new TaskException("Registry.Security", Key);
            }
          }
    }
}
