//-----------------------------------------------------------------------
// <copyright file="Resources.cs" company="Microsoft">
// Copyright (c) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY 
// KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
// </copyright>
// <author>Andy Reeves</author>
// <email>andyr</email>
// <date>2004-04-13</date>
// <summary>Provides Resources to all the tasks.</summary>
//-----------------------------------------------------------------------

namespace Microsoft.Sdc.Tasks
{
    using System;
    using System.Resources;
    using System.Reflection;

    /// <summary>
    /// Provides Resources to all the tasks.
    /// </summary>
    internal sealed class Resources
    {
        private static readonly ResourceManager resources = null;
        
        /// <summary>
        /// Creates a static ResourceManager for this assembly.
        /// </summary>
        static Resources()
        {
            Assembly assembly = Assembly.GetExecutingAssembly();
            resources = new ResourceManager(assembly.GetName().Name + ".Strings", assembly);
        }
        
        /// <summary>
        /// Prevents a new instance of the Resources class being instantiated.
        /// </summary>
        private Resources()
        {
        }

        /// <summary>
        /// Returns a ResourceManager for this assembly.
        /// </summary>
        /// <returns>An instance of a ResourceManager class.</returns>
        internal static ResourceManager GetResourceManager()
        {
            return resources;
        }
    }
}