﻿//-----------------------------------------------------------------------
// <copyright file="StringComparison.cs" company="Microsoft">
// Copyright (c) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY 
// KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
// </copyright>
// <author>Andy Reeves</author>
// <email>andyr</email>
// <date>2004-11-09</date>
// <summary>
// Compares the 2 params according to Comparison and returns result
// </summary>
//-----------------------------------------------------------------------

namespace Microsoft.Sdc.Tasks
{
    #region Using directives
    using System;
    using System.Text;
    using Microsoft.Build.BuildEngine;
    using Microsoft.Build.Framework;
    using Microsoft.Build.Utilities;
    using Microsoft.Build.Shared;
    #endregion

    public class StringComparison : TaskBase
    {
        private string param1;
        private string param2;
        private string comparison;
        private bool result;

        public StringComparison()
        {
        }

        [Output]
        public bool Result
        {
            get { return this.result; }
            set { this.result = value; }
        }

        public string Param1
        {
            get { return this.param1; }
            set { this.param1 = value; }
        }

        public string Param2
        {
            get { return this.param2; }
            set { this.param2 = value; }
        }

        /// <summary>
        /// Supports 'GreaterThan', 'LessThan', 'GreaterThanOrEquals', 'LessThanOrEquals', 'Contains', 'StartsWith', 'EndsWith'
        /// </summary>
        /// <value></value>
        public string Comparison
        {
            get { return this.comparison; }
            set { this.comparison = value; }
        }     

        protected override void InternalExecute()
        {
            this.result = false;

            if (param1 == null) param1 = string.Empty;

            switch (this.comparison.ToLowerInvariant())
            {
                case "greaterthan":
                    {
                        if (this.param1.CompareTo(this.param2) > 0)
                        {
                            this.result = true;
                        }
                        break;
                    }

                case "lessthan":
                    {
                        if (this.param1.CompareTo(this.param2) < 0)
                        {
                            this.result = true;
                        }
                        break;
                    }

                case "greaterthanorequals":
                    {
                        if (this.param1.CompareTo(this.param2) >= 0)
                        {
                            this.result = true;
                        }
                        break;
                    }

                case "lessthanorequals":
                    {
                        if (this.param1.CompareTo(this.param2) <= 0)
                        {
                            this.result = true;
                        }
                        break;
                    }
                case "contains":
                    {
                        if (this.param1.Contains(this.param2))
                        {
                            this.result = true;
                        }
                        break;
                    }
                case "startswith":
                    {
                        if (this.param1.StartsWith(this.param2))
                        {
                            this.result = true;
                        }
                        break;
                    }
                case "endswith":
                    {
                        if (this.param1.EndsWith(this.param2))
                        {
                            this.result = true;
                        }
                        break;
                    }
            }
        }
    }
}
