﻿//-----------------------------------------------------------------------
// <copyright file="Load.cs" company="Microsoft">
// Copyright (c) Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY 
// KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
// </copyright>
// <author>Mark Phillips</author>
// <email>v-mphill@microsoft.com</email>
// <date>2004-05-24</date>
// <summary>Starts a virtual machine.</summary>
//-----------------------------------------------------------------------

namespace Microsoft.Sdc.Tasks.VirtualServer
{
    #region Using directives
    using System;
    using System.Reflection;
    using System.Collections;
    using System.Globalization;
    using System.Runtime.InteropServices;
    using Microsoft.Sdc.Tasks.VirtualServer;
    using Microsoft.Build.Framework;
    #endregion

    /// <summary>
    /// TODO
    /// Loads Virtual Server info.
    /// </summary>          
    /// <remarks>
    /// <code><![CDATA[
    /// <VirtualServer.VirtualMachine.Start
    ///             MachineName="machineName"
    ///             ServerName="serverName"
    ///             Timeout="timeout">
    /// </VirtualServer.VirtualMachine.Start>
    /// ]]></code>
    /// <para>where:</para>
    /// <para><i>machineName (Required)</i></para>
    /// <para>The name of the virtual machine to be started.</para>
    /// <para><i>serverName</i></para>
    /// <para>Set the <i>serverName</i> property to specify a remote server to connect to. Defaults to connect locally.</para>
    /// <para><i>timeout</i></para>
    /// <para>Length of time to wait for the start task to complete, in milliseconds. Defaults to 10.</para>
    /// </remarks>
    /// <example>
    /// <code><![CDATA[
    /// <Project>
    ///     <Target Name="Test" >
    ///         <VirtualServer.VirtualMachine.Start
    ///             MachineName="myMachine"
    ///             Timeout="20"
    ///         </VirtualServer.VirtualMachine.Start> 
    ///     </Target>
    /// </Project>
    /// ]]></code>    
    /// </example>
    public class Load : VirtualServerBase
    {
        private string serverName;
        private string defaultConfigurationPath;
        
        /// <summary>
        /// Initializes a new instance of the Load class.
        /// </summary>
        public Load()
        {
        }

        /// <summary>
        /// Performs the action of this task.
        /// </summary>
        protected override void InternalExecute()
        {
            ComWrapper virtualServer = GetVirtualServer(this.serverName);
            this.defaultConfigurationPath = (string)virtualServer.GetProperty("DefaultVMConfigurationPath");
        }

        /// <summary>
        /// Set the <i>serverName</i> property to specify a remote server to connect to.
        /// </summary>
        /// <value>Set the <i>serverName</i> property to specify a remote server to connect to. Defaults to connect locally.</value>
        public string ServerName
        {
            get
            {
                return (serverName == null ? String.Empty : serverName);
            }
            set
            {
                serverName = value;
            }
        }

        /// <summary>
        /// Default virtual machine configurations directory path. The path string returned is terminated by a trailing \ character. 
        /// </summary>
        /// <value>By default, this property value is set to the "%ALLUSERSPROFILE%\Documents\Shared Virtual Machines\" directory.</value>
        [Output]
        public string DefaultConfigurationPath
        {
            get
            {
                return (this.defaultConfigurationPath == null ? String.Empty : this.defaultConfigurationPath);
            }
            set
            {
                this.defaultConfigurationPath = value;
            }
        }
    }
}